# Generated by Django 5.0.2 on 2024-03-02 21:57

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="ConfigEntry",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, unique=True)),
                (
                    "kind",
                    models.CharField(
                        choices=[
                            ("yaml", "YAML"),
                            ("json", "JSON"),
                            ("env", "Environment variables"),
                            ("text", "Any text"),
                        ],
                        max_length=4,
                    ),
                ),
                ("contents", models.TextField()),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
            ],
            options={
                "verbose_name": "Config Entry",
                "verbose_name_plural": "Config Entries",
            },
        ),
    ]
